==============
tmuxp Glossary
==============


.. glossary::

    tmuxp
        A tool to manage workspaces with tmux. A pythonic abstraction of
        tmux.

    tmux(1)
        The tmux binary. Used internally to distinguish tmuxp is only a
        layer on top of tmux.

    kaptan
        configuration management library, see `kaptan on github`_.

.. _kaptan on github: https://github.com/emre/kaptan
